@@ -150,24 +150,23 @@ sub install_with_cpanfile {
     $self->install("--installdeps", "--cpanfile", $path, ".");
 }
 
-sub fatscript {
-    my $self = shift;
-    Module::Metadata->find_module_by_name("App::cpanminus::fatscript")
-        or die "Can't locate App::cpanminus::fatscript";
-}
-
 sub install {
     my($self, @args) = @_;
 
     my $dir = Path::Tiny->tempdir;
     local $ENV{PERL_CPANM_HOME} = $dir;
     local $ENV{PERL_CPANM_OPT};
-    system $^X, $self->fatscript,
-      ($self->verbose ? () : "--quiet"),
-      "--notest",
-      "--save-dists", $self->repository_base->child('cache'),
-      "-L", $self->repository_base->child('perl5'),
-      @args;
+
+    require Menlo::CLI::Compat;
+
+    my $cli = Menlo::CLI::Compat->new(
+        ($self->verbose ? () : "--quiet"),
+        "--notest",
+        "--save-dists", $self->repository_base->child('cache'),
+        "-L", $self->repository_base->child('perl5'),
+        @args,
+    );
+    $cli->run;
 
     for my $ent ($dir->child("latest-build")->children) {
         next unless $ent->is_dir && $ent->child("blib/meta/install.json")->exists;
@@ -176,14 +175,17 @@ sub install {
 }
 
 sub quote {
-    require Data::Dump;
+    my $indent = shift;
+    $indent = " " x $indent;
 
-    my $value = transform(@_);
-    if (ref $value) {
-        Data::Dump::dump($value);
-    } else {
-        Data::Dump::quote($value);
-    }
+    require Data::Dumper;
+    my $val = Data::Dumper->new([transform(@_)], [])
+      ->Sortkeys(1)->Terse(1)->Indent(1)->Dump;
+
+    chomp $val;
+    $val =~ s/^/$indent/mg if $indent;
+    $val =~ s/^ *//;
+    $val;
 }
 
 sub transform {
@@ -233,12 +235,12 @@ sub dump_bootstrap {
 package $package;
 
 our %environment = (
-inc     => @{[ quote \@inc ]},
-path    => @{[ quote \@path ]},
-execs   => @{[ quote \%execs ]},
-base    => @{[ quote(Path::Tiny->cwd) ]},
-modules => @{[ quote \%modules ]},
-prereqs => @{[ quote $prereqs ]},
+  'inc' => @{[ quote 2, \@inc ]},
+  'path' => @{[ quote 2, \@path ]},
+  'execs' => @{[ quote 2, \%execs ]},
+  'base' => @{[ quote(2, Path::Tiny->cwd) ]},
+  'modules' => @{[ quote 2, \%modules ]},
+  'prereqs' => @{[ quote 2, $prereqs ]},
 );
 
 1;
@@ -388,7 +390,11 @@ sub cmd_package {
             require File::Fetch;
             print "Fetching ", $package->pathname, " from CPAN\n";
             my $fetch = File::Fetch->new(uri => "http://backpan.perl.org/authors/id/" . $package->pathname);
-            $fetch->fetch(to => $target->parent) or warn $fetch->error;
+            if ($fetch->fetch(to => $target->parent)) {
+                $success++;
+            } else {
+                warn $fetch->error;
+            }
         }
     }
 
